@@ -8,6 +8,7 @@ import yaml
 # DEFAULT_AMI = "ami-08cf5e5716f79b01a"  # Jupyter-tmsn, us-east-1
 DEFAULT_AMI = "ami-0fc359be23c460554"  # us-west-2
 DEFAULT_REGION = "us-west-2"
+DEFAULT_TYPE = "m3.xlarge"
 
 def load_config(args, config_path="~/.tmsn_config"):
     def load_credential(config):
@@ -26,6 +27,12 @@ def load_config(args, config_path="~/.tmsn_config"):
         with open(config_path) as f:
             config = yaml.safe_load(f)
     # Load arguments
+    if "type" not in args or args["type"] is None:
+        print("Instance type is not specified. Default instance type set to '{}'".format(
+            DEFAULT_TYPE))
+        args["type"] = DEFAULT_TYPE
+    if "spot" not in args or args["spot"] is None:
+        args["spot"] = 0.0
     if "ami" not in args or args["ami"] is None:
         args["ami"] = DEFAULT_AMI
         print("AMI is not specified. Default AMI set to '{}'".format(args["ami"]))
